A Star-Wars like opening title
-------------------------------

This is an approximate effect (the perspective would require some more complex transformations) but it is a nice exercise. 

Warning: clip with sound.

.. raw:: html

        <center>
        <object><param name="movie"
        value="http://www.youtube.com/v/5euLdo8L0o0&hl=en_US&fs=1&rel=0">
        </param><param name="allowFullScreen" value="true"></param><param
        name="allowscriptaccess" value="always"></param><embed
        src="http://www.youtube.com/v/5euLdo8L0o0&hl=en_US&fs=1&rel=0"
        type="application/x-shockwave-flash" allowscriptaccess="always"
        allowfullscreen="true" width="550" height="450"></embed></object>
        </center>

Let us also have a look at this tutorial which shows the different steps:

.. raw:: html

        <center>
        <object><param name="movie"
        value="http://www.youtube.com/v/dGrP7GhzWEE&hl=en_US&fs=1&rel=0">
        </param><param name="allowFullScreen" value="true"></param><param
        name="allowscriptaccess" value="always"></param><embed
        src="http://www.youtube.com/v/dGrP7GhzWEE&hl=en_US&fs=1&rel=0"
        type="application/x-shockwave-flash" allowscriptaccess="always"
        allowfullscreen="true" width="550" height="450"></embed></object>
        </center>
        
And here you are for the code, and for the code of the tutorial.

.. literalinclude:: ../../examples/star_worms.py
